@@ -53,7 +53,7 @@ use 5.008;
 use File::Basename;
 use filetest 'access';
 use Cwd;
-use lib '/usr/share/devscripts';
+BEGIN { push @INC, '/usr/share/devscripts'; }
 use Devscripts::Compression;
 use IO::Handle;  # for flushing
 use vars qw(*BUILD *OLDOUT *OLDERR);  # prevent a warning
